@@ -4,12 +4,20 @@ from typing import Dict, Generator, List
 
 import httpx
 import yaml
-from chaoslib.discovery.discover import discover_probes, initialize_discovery_result
+from chaoslib.discovery.discover import (
+    discover_probes,
+    initialize_discovery_result,
+)
 from chaoslib.exceptions import ActivityFailed
-from chaoslib.types import Configuration, DiscoveredActivities, Discovery, Secrets
+from chaoslib.types import (
+    Configuration,
+    DiscoveredActivities,
+    Discovery,
+    Secrets,
+)
 from logzero import logger
 
-__version__ = "0.4.2"
+__version__ = "0.5.0"
 __all__ = ["get_session", "discover"]
 RELIABLY_CONFIG_PATH = "~/.config/reliably/config.yaml"
 RELIABLY_HOST = "reliably.com"
@@ -66,9 +74,9 @@ def get_auth_info(
         reliably_config_path = None
 
     secrets = secrets or {}
-    reliably_token = secrets.get("token")
-    reliably_host = secrets.get("host")
-    reliably_org = secrets.get("org")
+    reliably_token = secrets.get("token", os.getenv("RELIABLY_TOKEN"))
+    reliably_host = secrets.get("host", os.getenv("RELIABLY_HOST"))
+    reliably_org = secrets.get("org", os.getenv("RELIABLY_ORG"))
 
     if not reliably_token and reliably_config_path:
         logger.debug(f"Loading Reliably config from: {reliably_config_path}")
