@@ -1,3 +1,4 @@
+from datetime import datetime, timezone
 from typing import Any, Dict, List, cast
 
 from chaoslib.types import (
@@ -16,6 +17,7 @@ from chaosreliably.types import (
     EntityContext,
     EntityContextExperimentEventLabels,
     EntityContextExperimentLabels,
+    EntityContextExperimentResultEventAnnotations,
     EntityContextExperimentRunLabels,
     EntityContextExperimentVersionLabels,
     EntityContextMetadata,
@@ -45,26 +47,32 @@ def before_experiment_control(
     """
     Control run *before* the execution of an Experiment.
 
-    For a given Experiment, the control creates (if not already created) an Experiment
-    Entity Context and an Experiment Version Entity Context in the Reliably service.
+    For a given Experiment, the control creates (if not already created) an
+    Experiment
 
-    A unique Experiment Run Entity Context is also created, with an Experiment Event
-    Entity Context of type `EXPERIMENT_START` created, relating to the run.
+    Entity Context and an Experiment Version Entity Context in the Reliably
+    service.
 
-    The control requires the `arguments` of `commit_hash`, `source`, and `user` to be
-    provided to the control definition. If not provided, the control will simply not
-    create any Entity Contexts.
+    A unique Experiment Run Entity Context is also created, with an Experiment
+    Event. Entity Context of type `EXPERIMENT_START` created, relating to the
+    run.
 
-    Once the Entity Contexts have been created, an entry into the configuration is made
-    under configuration["chaosreliably"]["experiment_run_labels"] to allow for
-    other controls to create events relating to the Experiment Run.
+    The control requires the `arguments` of `commit_hash`, `source`, and `user`
+    to be provided to the control definition. If not provided, the control will
+    simply not create any Entity Contexts.
 
-    :param context: Experiment object representing the Experiment that will be executed
+    Once the Entity Contexts have been created, an entry into the configuration
+    is made under configuration["chaosreliably"]["experiment_run_labels"] to
+    allow for other controls to create events relating to the Experiment Run.
+
+    :param context: Experiment object representing the Experiment that will be
+        executed
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :param **kwargs: Expected required `kwargs` are 'commit_hash' (str), `source` (str),
-        and `user` (str), optional is `experiment_related_to_labels`
-        (List[Dict[str, str]]) representing labels of entities the Experiment relates to
+    :param **kwargs: Expected required `kwargs` are 'commit_hash' (str),
+        `source` (str), and `user` (str), optional is
+        `experiment_related_to_labels` (List[Dict[str, str]]) representing
+        labels of entities the Experiment relates to
 
     Examples
     --------
@@ -113,13 +121,15 @@ def before_experiment_control(
         user = kwargs.get("user")
         if not commit_hash or not source or not user:
             logger.debug(
-                "The parameters: `commit_hash`, `source`, and `user` are required for "
-                "the chaosreliably controls, please provide them. This Experiment Run"
-                " will not be tracked with Reliably."
+                "The parameters: `commit_hash`, `source`, and `user` are "
+                "required for the chaosreliably controls, please provide "
+                "them. This Experiment Run will not be tracked with Reliably."
             )
             return
 
-        experiment_related_to_labels = kwargs.get("experiment_related_to_labels") or []
+        experiment_related_to_labels = kwargs.get(
+            "experiment_related_to_labels", []
+        )
 
         experiment_run_labels = (
             _create_experiment_entities_for_before_experiment_control(
@@ -138,9 +148,10 @@ def before_experiment_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, whilst running the Before Experiment control, "
-            "no further entities will be created, the Experiment execution won't be "
-            "affected"
+            f"An error occurred: {ex}, whilst running the Before Experiment "
+            "control, no further entities will be created, the Experiment "
+            "execution won't be affected",
+            exc_info=True,
         )
 
 
@@ -159,7 +170,8 @@ def after_experiment_control(
 
     The Event has the `event_type` of `EXPERIMENT_END`
 
-    :param context: Experiment object representing the Experiment that was executed
+    :param context: Experiment object representing the Experiment that was
+        executed
     :param state: Journal object representing the state of the Experiment after
         execution
     :param configuration: Configuration object provided by Chaos Toolkit
@@ -180,8 +192,9 @@ def after_experiment_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the After Experiment control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the After Experiment "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -192,15 +205,17 @@ def before_hypothesis_control(
     **kwargs: Any,
 ) -> None:
     """
-    Control run *before* the execution of an Experiments Steady State Hypothesis.
+    Control run *before* the execution of an Experiments Steady State
+    Hypothesis.
 
-    For a given Steady State Hypothesis, the control creates an Experiment Event Entity
+    For a given Steady State Hypothesis, the control creates an Experiment
+    Event Entity
     Context in the Reliably service.
 
     The Event has the `event_type` of `HYPOTHESIS_START`.
 
-    :param context: Hypothesis object representing the Steady State Hypothesis that is
-        to be executed
+    :param context: Hypothesis object representing the Steady State Hypothesis
+        that is to be executed
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -219,8 +234,9 @@ def before_hypothesis_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the Before Hypothesis control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the Before Hypothesis "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -232,15 +248,16 @@ def after_hypothesis_control(
     **kwargs: Any,
 ) -> None:
     """
-    Control run *after* the execution of an Experiments Steady State Hypothesis.
+    Control run *after* the execution of an Experiments Steady State
+    Hypothesis.
 
-    For a given Steady State Hypothesis and its state, post execution, the control
-    creates an Experiment Event Entity Context in the Reliably service.
+    For a given Steady State Hypothesis and its state, post execution, the
+    control creates an Experiment Event Entity Context in the Reliably service.
 
     The Event has the `event_type` of `HYPOTHESIS_END`.
 
-    :param context: Hypothesis object representing the Steady State Hypothesis that has
-        been executed
+    :param context: Hypothesis object representing the Steady State Hypothesis
+        that has been executed
     :param state: Dict[str, Any] representing the output of
         `run_steady_state_hypothesis` in `chaoslib`
     :param configuration: Configuration object provided by Chaos Toolkit
@@ -261,8 +278,9 @@ def after_hypothesis_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the After Hypothesis control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the After Hypothesis "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -275,12 +293,13 @@ def before_method_control(
     """
     Control run *before* the execution of an Experiments Method.
 
-    For a given Experiment, the control creates an Experiment Event Entity Context in
-    the Reliably service.
+    For a given Experiment, the control creates an Experiment Event Entity
+    Context in the Reliably service.
 
     The Event has the `event_type` of `METHOD_START`.
 
-    :param context: Experiment object representing the Experiment that will be executed
+    :param context: Experiment object representing the Experiment that will be
+        executed
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -299,8 +318,9 @@ def before_method_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the Before Method control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the Before Method "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -314,14 +334,16 @@ def after_method_control(
     """
     Control run *after* the execution of an Experiments Method.
 
-    For a given Experiment Method and its state, the control creates an Experiment
+    For a given Experiment Method and its state, the control creates an
+    Experiment
     Event Entity Context in the Reliably service.
 
     The Event has the `event_type` of `METHOD_END`.
 
-    :param context: Experiment object representing the Experiment that will be executed
-    :param state: List[Run] object presenting the executed Activities within the
-        Experiments Method
+    :param context: Experiment object representing the Experiment that will be
+        executed
+    :param state: List[Run] object presenting the executed Activities within
+        the Experiments Method
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -340,8 +362,9 @@ def after_method_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the After Method control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the After Method "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -354,12 +377,13 @@ def before_rollback_control(
     """
     Control run *before* the execution of an Experiments Rollback.
 
-    For a given Experiment, the control creates an Experiment Event Entity Context in
-    the Reliably service.
+    For a given Experiment, the control creates an Experiment Event Entity
+    Context in the Reliably service.
 
     The Event has the `event_type` of `ROLLBACK_START`.
 
-    :param context: Experiment object representing the Experiment that will be executed
+    :param context: Experiment object representing the Experiment that will be
+        executed
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -378,8 +402,9 @@ def before_rollback_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the Before Rollback control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the Before Rollback "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -393,14 +418,16 @@ def after_rollback_control(
     """
     Control run *after* the execution of an Experiments Rollback.
 
-    For a given Experiment Rollback and its state, the control creates an Experiment
+    For a given Experiment Rollback and its state, the control creates an
+    Experiment
     Event Entity Context in the Reliably service.
 
     The Event has the `event_type` of `ROLLBACK_END`.
 
-    :param context: Experiment object representing the Experiment that will be executed
-    :param state: List[Run] object presenting the executed Activities within the
-        Experiments Rollback
+    :param context: Experiment object representing the Experiment that will be
+        executed
+    :param state: List[Run] object presenting the executed Activities within
+        the Experiments Rollback
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -419,8 +446,9 @@ def after_rollback_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the After Rollback control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the After Rollback "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -433,8 +461,8 @@ def before_activity_control(
     """
     Control run *before* the execution of an Experiment Activity.
 
-    For a given Experiment Activity, the control creates an Experiment Event Entity
-    Context in the Reliably service.
+    For a given Experiment Activity, the control creates an Experiment Event
+    Entity Context in the Reliably service.
 
     The Event has the `event_type` of `ACTIVITY_START`.
 
@@ -458,8 +486,9 @@ def before_activity_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the Before Activity control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the Before Activity "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
@@ -473,14 +502,15 @@ def after_activity_control(
     """
     Control run *after* the execution of an Experiment Activity.
 
-    For a given Experiment Activity and its state, the control creates an Experiment
-    Event Entity Context in the Reliably service.
+    For a given Experiment Activity and its state, the control creates an "
+    Experiment Event Entity Context in the Reliably service.
 
     The Event has the `event_type` of `ACTIVITY_END`.
 
     :param context: Activity object representing the Experiment Activity
         that was executed
-    :param state: Run object representing the state of the executed Experiment Activity
+    :param state: Run object representing the state of the executed Experiment
+        Activity
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
     :param **kwargs: Any additional keyword arguments passed to the control
@@ -499,25 +529,39 @@ def after_activity_control(
         )
     except Exception as ex:
         logger.debug(
-            f"An error occurred: {ex}, while running the After Activity control, the"
-            " Experiment execution won't be affected."
+            f"An error occurred: {ex}, while running the After Activity "
+            "control, the Experiment execution won't be affected.",
+            exc_info=True,
         )
 
 
+###############################################################################
+# Private functions
+###############################################################################
 def _create_entity_context_on_reliably(
-    entity_context: EntityContext, configuration: Configuration, secrets: Secrets
+    entity_context: EntityContext,
+    configuration: Configuration,
+    secrets: Secrets,
 ) -> EntityContext:
     """
     For a given EntityContext, create it on the Reliably services.
 
-    :param entity_context: EntityContext which will be created on the Reliably service
+    :param entity_context: EntityContext which will be created on the Reliably
+        service
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContext representing the EntityContext that was just created
+    :returns: EntityContext representing the EntityContext that was just
+        created
     """
     with get_session(configuration, secrets) as session:
         url = "/entitycontext"
+        j = entity_context.json(by_alias=True, indent=2)
+        logger.debug(j)
         resp = session.post(url, content=entity_context.json(by_alias=True))
+        try:
+            logger.debug(resp.json())
+        finally:
+            pass
         resp.raise_for_status()
         return entity_context
 
@@ -535,23 +579,22 @@ def _create_experiment(
     :param experiment_title: str representing the name of the Experiment
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContextExperimentLabels representing the metadata labels of the
-        created entity - used for `relatedTo` properties in Reliably
+    :returns: EntityContextExperimentLabels representing the metadata labels of
+        the created entity - used for `relatedTo` properties in Reliably
     """
     experiment_entity = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title=experiment_title),
+            labels=EntityContextExperimentLabels(name=experiment_title),
             related_to=related_to_labels,
         )
     )
 
     created_entity = _create_entity_context_on_reliably(
-        entity_context=experiment_entity, configuration=configuration, secrets=secrets
-    )
-    return cast(
-        EntityContextExperimentLabels,
-        created_entity.metadata.labels.dict(by_alias=True),
+        entity_context=experiment_entity,
+        configuration=configuration,
+        secrets=secrets,
     )
+    return cast(EntityContextExperimentLabels, created_entity.metadata.labels)
 
 
 def _create_experiment_version(
@@ -565,20 +608,22 @@ def _create_experiment_version(
     For a given commit hash, source link, and Experiment labels, create a
     ExperimentVersion Entity Context on the Reliably services.
 
-    :param commit_hash: str representing the SHA1 Hash of the current commit of the
-        Experiments repo at the time of running it
+    :param commit_hash: str representing the SHA1 Hash of the current commit of
+        the Experiments repo at the time of running it
     :param source: str representing the URL to the source control location
         of the Experiment being run
-    :param experiment_labels: EntityContextExperimentLabels object representing the
-        labels of the Experiment this version is related to
+    :param experiment_labels: EntityContextExperimentLabels object representing
+        the labels of the Experiment this version is related to
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContextExperimentVersionLabels representing the metadata labels
-        of the created entity - used for `relatedTo` properties in Reliably
+    :returns: EntityContextExperimentVersionLabels representing the metadata
+        labels of the created entity - used for `relatedTo` properties in
+        Reliably
     """
     experiment_version_entity = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentVersionLabels(
+                name=experiment_labels.name,
                 commit_hash=commit_hash,
                 source=source,
             ),
@@ -592,8 +637,7 @@ def _create_experiment_version(
         secrets=secrets,
     )
     return cast(
-        EntityContextExperimentVersionLabels,
-        created_entity.metadata.labels.dict(by_alias=True),
+        EntityContextExperimentVersionLabels, created_entity.metadata.labels
     )
 
 
@@ -604,20 +648,25 @@ def _create_experiment_run(
     secrets: Secrets,
 ) -> EntityContextExperimentRunLabels:
     """
-    For a given user and Experiment Version labels, create a ExperimentRun Entity
-    Context on the Reliably services.
+    For a given user and Experiment Version labels, create a ExperimentRun
+    Entity Context on the Reliably services.
 
-    :param user: str representing the name of the user that is running the Experiment
-    :param experiment_version_labels: EntityContextExperimentVersionLabels object
-        representing the labels of the Experiment Version this run is related to
+    :param user: str representing the name of the user that is running the
+        Experiment
+    :param experiment_version_labels: EntityContextExperimentVersionLabels
+        object representing the labels of the Experiment Version this run is
+        related to
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContextExperimentRunLabels representing the metadata labels of
-        the created entity - used for `relatedTo` properties in Reliably
+    :returns: EntityContextExperimentRunLabels representing the metadata labels
+        of the created entity - used for `relatedTo` properties in Reliably
     """
     experiment_run_entity = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentRunLabels(user=user),
+            name=experiment_version_labels.name,
+            labels=EntityContextExperimentRunLabels(
+                user=user, name=experiment_version_labels.name
+            ),
             related_to=[experiment_version_labels],
         )
     )
@@ -628,8 +677,7 @@ def _create_experiment_run(
         secrets=secrets,
     )
     return cast(
-        EntityContextExperimentRunLabels,
-        created_entity.metadata.labels.dict(by_alias=True),
+        EntityContextExperimentRunLabels, created_entity.metadata.labels
     )
 
 
@@ -645,20 +693,42 @@ def _create_experiment_event(
     For a given event type, name, output, and Experiment Run labels, create a
     ExperimentEvent Entity Context on the Reliably services.
 
-    :param event_type: EventType representing the type of the Event that has happened
+    :param event_type: EventType representing the type of the Event that has
+        happened
     :param name: str representing the name of the Event in the Experiment
-    :param output: Any object representing the output of the event in the Experiment
+    :param output: Any object representing the output of the event in the
+        Experiment
     :param experiment_run_labels: EntityContextExperimentRunLabels object
         representing the labels of the Experiment Run this Event is related to
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContextExperimentEventLabels representing the metadata labels of
-        the created entity - used for `relatedTo` properties in Reliably
+    :returns: EntityContextExperimentEventLabels representing the metadata
+        labels of the created entity - used for `relatedTo` properties in
+        Reliably
     """
+    # until we have figured out where to store large outputs, we will not be
+    # sending it. Instead, we'll send enough information to make sense of the
+    # results.
+
+    s = e = None
+    if output and ("start" in output) and ("end" in output):
+        utc = timezone.utc
+        s = datetime.fromisoformat(output.get("start")).replace(tzinfo=utc)
+        e = datetime.fromisoformat(output.get("end")).replace(tzinfo=utc)
+    output = output or {}
     experiment_event_entity = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentEventLabels(
-                event_type=event_type.value, name=name, output=str(output)
+                event_type=event_type.value,
+                name=name,
+            ),
+            annotations=EntityContextExperimentResultEventAnnotations(
+                status=output.get("status", "unknown"),
+                deviated=str(output.get("deviated")).lower(),
+                duration=str(output.get("duration")),
+                started=s,
+                ended=e,
+                node=output.get("node"),
             ),
             related_to=[experiment_run_labels],
         )
@@ -670,8 +740,7 @@ def _create_experiment_event(
         secrets=secrets,
     )
     return cast(
-        EntityContextExperimentEventLabels,
-        created_entity.metadata.labels.dict(by_alias=True),
+        EntityContextExperimentEventLabels, created_entity.metadata.labels
     )
 
 
@@ -686,23 +755,24 @@ def _create_experiment_entities_for_before_experiment_control(
 ) -> EntityContextExperimentRunLabels:
     """
     For a given Experiment title, commit hash, source link and user, create
-    an Experiment, Experiment Version, Experiment Run, and Experiment start Entity
-    Context on the Reliably services.
+    an Experiment, Experiment Version, Experiment Run, and Experiment start
+    Entity Context on the Reliably services.
 
-    If the Experiment and version already exist, new ones will not be created, however
-    a new run is *always* created.
+    If the Experiment and version already exist, new ones will not be created,
+    however a new run is *always* created.
 
     :param experiment_title: str representing the name of the Experiment
-    :param commit_hash: str representing the SHA1 Hash of the current commit of the
-        Experiments repo at the time of running it
+    :param commit_hash: str representing the SHA1 Hash of the current commit of
+        the Experiments repo at the time of running it
     :param source: str representing the URL to the source control location
         of the Experiment being run
-    :param user: str representing the name of the user that is running the Experiment
+    :param user: str representing the name of the user that is running the
+        Experiment
     :param configuration: Configuration object provided by Chaos Toolkit
     :param secrets: Secret object provided by Chaos Toolkit
-    :returns: EntityContextExperimentRunLabels representing the metadata labels of
-        the Experiment Run entity - used for updating the configuration of the
-        Experiment so that Events may relate to it
+    :returns: EntityContextExperimentRunLabels representing the metadata labels
+        of the Experiment Run entity - used for updating the configuration of
+        the Experiment so that Events may relate to it
     """
     experiment_labels = _create_experiment(
         experiment_title=experiment_title,
