@@ -1,7 +1,7 @@
-from datetime import datetime
+from datetime import datetime, timedelta, timezone
 from tempfile import NamedTemporaryFile
 from typing import cast
-from unittest.mock import MagicMock, patch
+from unittest.mock import ANY, MagicMock, patch
 from uuid import uuid4
 
 import pytest
@@ -15,6 +15,7 @@ from chaosreliably.types import (
     EntityContext,
     EntityContextExperimentEventLabels,
     EntityContextExperimentLabels,
+    EntityContextExperimentResultEventAnnotations,
     EntityContextExperimentRunLabels,
     EntityContextExperimentVersionLabels,
     EntityContextMetadata,
@@ -26,23 +27,24 @@ def test_create_entity_context_on_reliably_correctly_calls_reliably_api(
     httpx_mock: pytest_httpx._httpx_mock.HTTPXMock,
 ) -> None:
     title = "A Test Experiment Title"
-    request_url = (
-        "https://reliably.com/api/entities/test-org/" "reliably.com/v1/entitycontext"
-    )
+    request_url = "https://reliably.com/api/entities/test-org/reliably.com/v1/entitycontext"  # noqa: E501
     expected_entity = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title=title),
+            labels=EntityContextExperimentLabels(name=title),
         )
     )
     httpx_mock.add_response(
         method="POST",
         url=request_url,
         match_content=expected_entity.json(by_alias=True).encode("utf-8"),
+        json={"id": "1234"},
     )
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {
+                    "reliably.com": {"token": "12345", "username": "jane"}
+                },
                 "currentOrg": {"name": "test-org"},
             },
             f,
@@ -64,11 +66,12 @@ def test_create_entity_context_on_reliably_raises_exception_if_response_not_ok(
 ) -> None:
     title = "A Test Experiment Title"
     request_url = (
-        "https://reliably.com/api/entities/test-org/" "reliably.com/v1/entitycontext"
+        "https://reliably.com/api/entities/test-org/"
+        "reliably.com/v1/entitycontext"  # noqa: E501
     )
     expected_entity = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title=title),
+            labels=EntityContextExperimentLabels(name=title),
         )
     )
     httpx_mock.add_response(
@@ -76,11 +79,14 @@ def test_create_entity_context_on_reliably_raises_exception_if_response_not_ok(
         url=request_url,
         match_content=expected_entity.json(by_alias=True).encode("utf-8"),
         status_code=500,
+        json={"id": "1234"},
     )
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {
+                    "reliably.com": {"token": "12345", "username": "jane"}
+                },
                 "currentOrg": {"name": "test-org"},
             },
             f,
@@ -98,13 +104,13 @@ def test_create_entity_context_on_reliably_raises_exception_if_response_not_ok(
 
 
 @patch("chaosreliably.controls.experiment._create_entity_context_on_reliably")
-def test_create_experiment_correct_calls_create_entity_context_and_returns_labels(
+def test_create_experiment_correct_calls_create_entity_context_and_returns_labels(  # noqa: E501
     mock_create_entity_context: MagicMock,
 ) -> None:
     title = "A Test Experiment Title"
     experiment_context = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title=title),
+            labels=EntityContextExperimentLabels(name=title),
         )
     )
     mock_create_entity_context.return_value = experiment_context
@@ -113,7 +119,7 @@ def test_create_experiment_correct_calls_create_entity_context_and_returns_label
         experiment_title=title, configuration=None, secrets=None
     )
 
-    assert labels == experiment_context.metadata.labels.dict(by_alias=True)
+    assert labels == experiment_context.metadata.labels
     mock_create_entity_context.assert_called_once_with(
         entity_context=experiment_context, configuration=None, secrets=None
     )
@@ -130,7 +136,7 @@ def test_create_experiment_with_related_to_labels_correct_calls_create_entity_co
     ]
     experiment_context = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title=title),
+            labels=EntityContextExperimentLabels(name=title),
             related_to=related_to_labels,
         )
     )
@@ -143,27 +149,31 @@ def test_create_experiment_with_related_to_labels_correct_calls_create_entity_co
         secrets=None,
     )
 
-    assert labels == experiment_context.metadata.labels.dict(by_alias=True)
+    assert labels == experiment_context.metadata.labels
     mock_create_entity_context.assert_called_once_with(
         entity_context=experiment_context, configuration=None, secrets=None
     )
 
 
 @patch("chaosreliably.controls.experiment._create_entity_context_on_reliably")
-def test_create_experiment_version_calls_create_entity_context_and_returns_labels(
+def test_create_experiment_version_calls_create_entity_context_and_returns_labels(  # noqa: E501
     mock_create_entity_context: MagicMock,
 ) -> None:
     commit_hash = "59f9f577e2d90719098f4d23d26329ce41f2d0bd"
-    source = "https://github.com/chaostoolkit-incubator/chaostoolkit-reliably/exp.json"
+    source = "https://github.com/chaostoolkit-incubator/chaostoolkit-reliably/exp.json"  # noqa: E501
     experiment_context = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentLabels(title="A Test Experiment Title"),
+            labels=EntityContextExperimentLabels(
+                name="A Test Experiment Title"
+            ),
         )
     )
     experiment_version_context = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentVersionLabels(
-                commit_hash=commit_hash, source=source
+                commit_hash=commit_hash,
+                source=source,
+                name=experiment_context.metadata.labels.name,
             ),
             related_to=[experiment_context.metadata.labels],
         )
@@ -180,9 +190,11 @@ def test_create_experiment_version_calls_create_entity_context_and_returns_label
         secrets=None,
     )
 
-    assert labels == experiment_version_context.metadata.labels.dict(by_alias=True)
+    assert labels == experiment_version_context.metadata.labels
     mock_create_entity_context.assert_called_once_with(
-        entity_context=experiment_version_context, configuration=None, secrets=None
+        entity_context=experiment_version_context,
+        configuration=None,
+        secrets=None,
     )
 
 
@@ -198,6 +210,7 @@ def test_create_experiment_run_calls_create_entity_context_and_returns_labels(
     experiment_version_context = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentVersionLabels(
+                name="Hello",
                 commit_hash="59f9f577e2d90719098f4d23d26329ce41f2d0bd",
                 source="https://github.com/chaostoolkit-incubator/chaostoolkit-reliably/exp.json",  # noqa
             )
@@ -206,7 +219,7 @@ def test_create_experiment_run_calls_create_entity_context_and_returns_labels(
     mock_uuid4.return_value = uuid4()
     experiment_run_context = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentRunLabels(user=user),
+            labels=EntityContextExperimentRunLabels(user=user, name="Hello"),
             related_to=[experiment_version_context.metadata.labels],
         )
     )
@@ -222,7 +235,7 @@ def test_create_experiment_run_calls_create_entity_context_and_returns_labels(
         secrets=None,
     )
 
-    assert labels == experiment_run_context.metadata.labels.dict(by_alias=True)
+    assert labels == experiment_run_context.metadata.labels
     mock_create_entity_context.assert_called_once_with(
         entity_context=experiment_run_context, configuration=None, secrets=None
     )
@@ -235,18 +248,37 @@ def test_create_experiment_run_calls_create_entity_context_and_returns_labels(
 def test_create_experiment_event_calls_create_entity_context_and_returns_labels(
     mock_create_entity_context: MagicMock,
 ) -> None:
+    event_start = datetime.utcnow()
+    event_end = event_start + timedelta(milliseconds=100)
     event_type = EventType.EXPERIMENT_START
     event_name = "A Start Event"
-    event_output = str([1, 2, 3])
+    event_output = {
+        "status": "failed",
+        "deviated": True,
+        "duration": 0.1,
+        "node": "localhost",
+        "start": event_start.isoformat(),
+        "end": event_end.isoformat(),
+    }
     experiment_run_context = EntityContext(
         metadata=EntityContextMetadata(
-            labels=EntityContextExperimentRunLabels(user="TestUser"),
+            labels=EntityContextExperimentRunLabels(
+                user="TestUser", name="Hello"
+            ),
         )
     )
     experiment_event_context = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentEventLabels(
-                event_type=event_type.value, name=event_name, output=event_output
+                event_type=event_type.value, name=event_name
+            ),
+            annotations=EntityContextExperimentResultEventAnnotations(
+                status=event_output.get("status", "unknown"),
+                deviated=str(event_output.get("deviated")).lower(),
+                duration=str(event_output.get("duration")),
+                started=event_start.replace(tzinfo=timezone.utc),
+                ended=event_end.replace(tzinfo=timezone.utc),
+                node=event_output.get("node"),
             ),
             related_to=[experiment_run_context.metadata.labels],
         )
@@ -258,13 +290,33 @@ def test_create_experiment_event_calls_create_entity_context_and_returns_labels(
         name=event_name,
         output=event_output,
         experiment_run_labels=cast(
-            EntityContextExperimentRunLabels, experiment_run_context.metadata.labels
+            EntityContextExperimentRunLabels,
+            experiment_run_context.metadata.labels,
         ),
         configuration=None,
         secrets=None,
     )
+    annotations = {
+        "ctk_event_timestamp": ANY,
+        "ctk_event_output": None,
+        "ctk_experiment_run_status": "failed",
+        "ctk_experiment_run_deviated": "true",
+        "ctk_experiment_run_duration": "0.1",
+        "ctk_experiment_run_started": event_start.replace(tzinfo=timezone.utc),
+        "ctk_experiment_run_ended": event_end.replace(tzinfo=timezone.utc),
+        "ctk_experiment_run_node": "localhost",
+    }
 
-    assert labels == experiment_event_context.metadata.labels.dict(by_alias=True)
+    assert labels == experiment_event_context.metadata.labels
+
+    # purely for mypy's sake https://github.com/python/mypy/issues/4805#issuecomment-1018892112  # noqa E501
+    assert experiment_event_context.metadata.annotations is not None
+    assert annotations == experiment_event_context.metadata.annotations.dict(
+        by_alias=True
+    )
+
     mock_create_entity_context.assert_called_once_with(
-        entity_context=experiment_event_context, configuration=None, secrets=None
+        entity_context=experiment_event_context,
+        configuration=None,
+        secrets=None,
     )
