@@ -21,7 +21,7 @@ def test_that_get_objective_results_by_label_returns_correct_results(
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"  # noqa: E501
         f"?objective-match={encoded_labels}&limit=1"
     )
     httpx_mock.add_response(method="GET", url=request_url, json=results[:1])
@@ -29,7 +29,9 @@ def test_that_get_objective_results_by_label_returns_correct_results(
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {
+                    "reliably.com": {"token": "12345", "username": "jane"}
+                },
                 "currentOrg": {"name": "test-org"},
             },
             f,
@@ -38,7 +40,9 @@ def test_that_get_objective_results_by_label_returns_correct_results(
         )
         f.seek(0)
         res = get_objective_results_by_labels(
-            labels=labels, configuration={"reliably_config_path": f.name}, secrets=None
+            labels=labels,
+            configuration={"reliably_config_path": f.name},
+            secrets=None,
         )
         assert len(res) == 1
 
@@ -54,7 +58,7 @@ def test_that_get_objective_results_by_label_raises_exception_if_non_200(
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"  # noqa: E501
         f"?objective-match={encoded_labels}&limit=1"
     )
     httpx_mock.add_response(method="GET", url=request_url, status_code=400)
@@ -63,7 +67,9 @@ def test_that_get_objective_results_by_label_raises_exception_if_non_200(
         with NamedTemporaryFile(mode="w") as f:
             yaml.safe_dump(
                 {
-                    "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
+                    "auths": {
+                        "reliably.com": {"token": "12345", "username": "jane"}
+                    },
                     "currentOrg": {"name": "test-org"},
                 },
                 f,
@@ -89,7 +95,7 @@ def test_that_get_objective_results_by_label_passes_limit_parameter_correctly(
         ",".join([f"{key}={value}" for key, value in labels.items()])
     )
     request_url = (
-        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"
+        "https://reliably.com/api/entities/test-org/reliably.com/v1/objectiveresult"  # noqa: E501
         f"?objective-match={encoded_labels}&limit=20"
     )
     httpx_mock.add_response(method="GET", url=request_url, json=results)
@@ -97,7 +103,9 @@ def test_that_get_objective_results_by_label_passes_limit_parameter_correctly(
     with NamedTemporaryFile(mode="w") as f:
         yaml.safe_dump(
             {
-                "auths": {"reliably.com": {"token": "12345", "username": "jane"}},
+                "auths": {
+                    "reliably.com": {"token": "12345", "username": "jane"}
+                },
                 "currentOrg": {"name": "test-org"},
             },
             f,
